"use strict";

exports.__esModule = true;
exports.CAspectRatio = void 0;

var _vue = require("vue");

var _utils = require("@chakra-ui/utils");

var _vueSystem = require("@chakra-ui/vue-system");

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !(0, _vue.isVNode)(s);
}

/**
 * Vue component used to cropping media (videos, images and maps)
 * to a desired aspect ratio.
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/aspect-ratio
 */
var CAspectRatio = (0, _vue.defineComponent)({
  name: 'CAspectRatio',
  props: {
    ratio: {
      type: [Number],
      "default": 4 / 3
    }
  },
  setup: function setup(props, _ref) {
    var slots = _ref.slots,
        attrs = _ref.attrs;
    return function () {
      return (0, _vue.createVNode)(_vueSystem.chakra.div, (0, _vue.mergeProps)({
        "__label": "aspect-ratio",
        "position": "relative",
        "_before": {
          height: 0,
          content: "\"\"",
          display: 'block',
          paddingBottom: (0, _utils.mapResponsive)(props.ratio, function (r) {
            return 1 / r * 100 + "%";
          })
        },
        "__css": {
          '& > *:not(style)': {
            overflow: 'hidden',
            position: 'absolute',
            top: '0',
            right: '0',
            bottom: '0',
            left: '0',
            display: 'flex',
            justifyContent: 'center',
            alignItems: 'center',
            width: '100%',
            height: '100%'
          },
          '& > img, & > video': {
            objectFit: 'cover'
          }
        }
      }, attrs), _isSlot(slots) ? slots : {
        "default": function _default() {
          return [slots];
        }
      });
    };
  }
});
exports.CAspectRatio = CAspectRatio;
//# sourceMappingURL=aspect-ratio.js.map