"use strict";

exports.__esModule = true;
exports.CDivider = void 0;

var _vue = require("vue");

var _vueSystem = require("@chakra-ui/vue-system");

var _utils = require("@chakra-ui/utils");

var _vueUtils = require("@chakra-ui/vue-utils");

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/**
 * Layout component used to visually separate content in a list or group.
 * It display a thin horizontal or vertical line, and renders a `hr` tag.
 *
 * @see Docs https://vue.chakra-ui.com/docs/data-display/divider
 */
var CDivider = (0, _vue.defineComponent)({
  name: 'CDivider',
  props: _extends({
    orientation: {
      type: [String],
      "default": 'horizontal'
    }
  }, _vueUtils.vueThemingProps),
  setup: function setup(props, _ref) {
    var slots = _ref.slots,
        attrs = _ref.attrs;
    var themingProps = (0, _vue.computed)(function () {
      return (0, _utils.filterUndefined)({
        colorScheme: props.colorScheme,
        variant: props.variant,
        size: props.size,
        styleConfig: props.styleConfig,
        orientation: props.orientation
      });
    });
    var styles = (0, _vueSystem.useStyleConfig)('Divider', themingProps.value);

    var _styles$value = styles.value,
        borderLeftWidth = _styles$value.borderLeftWidth,
        borderBottomWidth = _styles$value.borderBottomWidth,
        borderTopWidth = _styles$value.borderTopWidth,
        borderRightWidth = _styles$value.borderRightWidth,
        borderWidth = _styles$value.borderWidth,
        borderStyle = _styles$value.borderStyle,
        borderColor = _styles$value.borderColor,
        stylesRest = _objectWithoutPropertiesLoose(_styles$value, ["borderLeftWidth", "borderBottomWidth", "borderTopWidth", "borderRightWidth", "borderWidth", "borderStyle", "borderColor"]);

    var dividerStyle = (0, _vue.computed)(function () {
      var dividerStyles = {
        vertical: {
          borderLeftWidth: borderLeftWidth || borderRightWidth || borderWidth || '1px',
          height: '100%'
        },
        horizontal: {
          borderBottomWidth: borderBottomWidth || borderTopWidth || borderWidth || '1px',
          width: '100%'
        }
      };
      return dividerStyles[props.orientation];
    });
    return function () {
      return (0, _vue.createVNode)(_vueSystem.chakra.hr, {
        "aria-orientation": props.orientation,
        "__css": _extends({}, stylesRest, {
          border: 0,
          borderColor: borderColor,
          borderStyle: borderStyle
        }, dividerStyle.value),
        "__label": "divider"
      }, {
        "default": function _default() {
          return [slots["default"] == null ? void 0 : slots["default"]()];
        }
      });
    };
  }
});
exports.CDivider = CDivider;
//# sourceMappingURL=divider.js.map