"use strict";

exports.__esModule = true;
exports.CLinkBox = exports.CLinkOverlay = void 0;

var _vue = require("vue");

var _vueSystem = require("@chakra-ui/vue-system");

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !(0, _vue.isVNode)(s);
}

var CLinkOverlay = (0, _vue.defineComponent)({
  name: 'CLinkOverlay',
  props: {
    as: {
      type: [Object, String],
      "default": 'a'
    },
    isExternal: Boolean
  },
  setup: function setup(props, _ref) {
    var slots = _ref.slots,
        attrs = _ref.attrs;
    return function () {
      return (0, _vue.createVNode)(_vueSystem.chakra.div, (0, _vue.mergeProps)({
        "as": props.as,
        "__label": "linkbox__overlay",
        "rel": props.isExternal ? 'noopener noreferrer' : undefined,
        "target": props.isExternal ? '_blank' : undefined,
        "__css": {
          position: 'static',
          '&::before': {
            content: "''",
            cursor: 'inherit',
            display: 'block',
            position: 'absolute',
            top: 0,
            left: 0,
            zIndex: 0,
            width: '100%',
            height: '100%'
          }
        }
      }, attrs), _isSlot(slots) ? slots : {
        "default": function _default() {
          return [slots];
        }
      });
    };
  }
});
exports.CLinkOverlay = CLinkOverlay;

/**
 * `LinkBox` is used to wrap content areas within a link while ensuring semantic html
 *
 * @see Docs https://vue.chakra-ui.com/docs/link-overlay
 * @see Resources https://www.sarasoueidan.com/blog/nested-links
 */
var CLinkBox = (0, _vue.defineComponent)({
  name: 'CLinkBox',
  props: {
    as: {
      type: [Object, String],
      "default": 'div'
    }
  },
  setup: function setup(props, _ref2) {
    var slots = _ref2.slots,
        attrs = _ref2.attrs;
    return function () {
      return (0, _vue.createVNode)(_vueSystem.chakra.div, (0, _vue.mergeProps)({
        "as": props.as,
        "__label": "linkbox",
        "position": "relative",
        "__css": {
          /* Elevates links and abbreviations */
          'a[href]:not(.chakra-linkbox__overlay), abbr[title]': {
            position: 'relative',
            zIndex: 1
          }
        }
      }, attrs), _isSlot(slots) ? slots : {
        "default": function _default() {
          return [slots];
        }
      });
    };
  }
});
exports.CLinkBox = CLinkBox;
//# sourceMappingURL=link-box.js.map