import { createVNode as _createVNode, isVNode as _isVNode, mergeProps as _mergeProps } from "vue";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import { computed, defineComponent } from 'vue';
import { chakra } from '@chakra-ui/vue-system';

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !_isVNode(s);
}

/**
 * Box is the most abstract component on top of which other chakra
 * components are built. It renders a `div` element by default.
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/box
 */
export var CBox = defineComponent({
  name: 'CBox',
  props: {
    as: {
      type: [String, Object],
      default: 'div'
    }
  },

  setup(props, _ref) {
    var {
      slots,
      attrs
    } = _ref;
    return () => _createVNode(chakra.div, _mergeProps({
      "as": props.as,
      "__label": "box"
    }, attrs), _isSlot(slots) ? slots : {
      default: () => [slots]
    });
  }

});
/**
 * As a constraint, you can't pass size related props
 * Only `size` would be allowed
 */

/**
 * CSquare is the `CBox` component implemented as a square
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/box
 */
export var CSquare = defineComponent({
  name: 'CSquare',
  props: {
    size: [Object, String, Number],
    centerContent: {
      type: [Boolean],
      default: true
    }
  },

  setup(props, _ref2) {
    var {
      slots,
      attrs
    } = _ref2;
    var styles = computed(() => props.centerContent ? {
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'center'
    } : {});
    return () => _createVNode(CBox, _mergeProps({
      "__label": "square",
      "boxSize": props.size,
      "__css": _extends({}, styles.value, {
        flexShrink: 0,
        flexGrow: 0
      })
    }, attrs), _isSlot(slots) ? slots : {
      default: () => [slots]
    });
  }

});
/**
 * CCircle is the `CBox` component implemented as a circle
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/box
 */

export var CCircle = defineComponent({
  name: 'CCircle',

  setup(_, _ref3) {
    var {
      slots,
      attrs
    } = _ref3;
    return () => _createVNode(CSquare, _mergeProps({
      "__label": "circle",
      "borderRadius": "9999px"
    }, attrs), _isSlot(slots) ? slots : {
      default: () => [slots]
    });
  }

});
//# sourceMappingURL=box.js.map