import { createVNode as _createVNode, isVNode as _isVNode, mergeProps as _mergeProps } from "vue";
import { defineComponent } from 'vue';
import { chakra } from '@chakra-ui/vue-system';

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !_isVNode(s);
}

/**
 * Vue component used to horizontally and vertically center its child.
 * It uses the popular `display: flex` centering technique.
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/center
 */
export var CCenter = defineComponent({
  name: 'CCenter',
  props: {
    as: {
      type: [String, Object],
      default: 'div'
    }
  },

  setup(props, _ref) {
    var {
      slots,
      attrs
    } = _ref;
    return () => {
      return _createVNode(chakra.div, _mergeProps({
        "__label": "center",
        "__css": {
          display: 'flex',
          alignItems: 'center',
          justifyContent: 'center'
        }
      }, props, attrs), _isSlot(slots) ? slots : {
        default: () => [slots]
      });
    };
  }

});
//# sourceMappingURL=center.js.map