import { createVNode as _createVNode, isVNode as _isVNode, mergeProps as _mergeProps } from "vue";
import { defineComponent } from 'vue';
import { chakra } from '@chakra-ui/vue-system';

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !_isVNode(s);
}

export var CLinkOverlay = defineComponent({
  name: 'CLinkOverlay',
  props: {
    as: {
      type: [Object, String],
      default: 'a'
    },
    isExternal: Boolean
  },

  setup(props, _ref) {
    var {
      slots,
      attrs
    } = _ref;
    return () => _createVNode(chakra.div, _mergeProps({
      "as": props.as,
      "__label": "linkbox__overlay",
      "rel": props.isExternal ? 'noopener noreferrer' : undefined,
      "target": props.isExternal ? '_blank' : undefined,
      "__css": {
        position: 'static',
        '&::before': {
          content: "''",
          cursor: 'inherit',
          display: 'block',
          position: 'absolute',
          top: 0,
          left: 0,
          zIndex: 0,
          width: '100%',
          height: '100%'
        }
      }
    }, attrs), _isSlot(slots) ? slots : {
      default: () => [slots]
    });
  }

});

/**
 * `LinkBox` is used to wrap content areas within a link while ensuring semantic html
 *
 * @see Docs https://vue.chakra-ui.com/docs/link-overlay
 * @see Resources https://www.sarasoueidan.com/blog/nested-links
 */
export var CLinkBox = defineComponent({
  name: 'CLinkBox',
  props: {
    as: {
      type: [Object, String],
      default: 'div'
    }
  },

  setup(props, _ref2) {
    var {
      slots,
      attrs
    } = _ref2;
    return () => {
      return _createVNode(chakra.div, _mergeProps({
        "as": props.as,
        "__label": "linkbox",
        "position": "relative",
        "__css": {
          /* Elevates links and abbreviations */
          'a[href]:not(.chakra-linkbox__overlay), abbr[title]': {
            position: 'relative',
            zIndex: 1
          }
        }
      }, attrs), _isSlot(slots) ? slots : {
        default: () => [slots]
      });
    };
  }

});
//# sourceMappingURL=link-box.js.map