import { createVNode as _createVNode, isVNode as _isVNode, mergeProps as _mergeProps } from "vue";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import { vueThemingProps } from '@chakra-ui/vue-utils';
import { defineComponent, computed } from 'vue';
import { chakra, useStyleConfig } from '@chakra-ui/vue-system';
import { filterUndefined } from '@chakra-ui/utils';

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !_isVNode(s);
}

/**
 * Links are accessible elements used primarily for navigation.
 *
 * It integrates well with other routing libraries like
 * Vue Router and Nuxt.js Link.
 *
 * @example
 *
 * ```vue
 * <CLink as="router-link" to="/home">Home</CLink>
 * ```
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/link
 */
export var CLink = defineComponent({
  name: 'CLink',
  props: _extends({
    as: {
      type: [Object, String],
      default: 'a'
    },
    isExternal: Boolean
  }, vueThemingProps),

  setup(props, _ref) {
    var {
      slots,
      attrs
    } = _ref;
    var themingProps = computed(() => filterUndefined({
      colorScheme: props.colorScheme,
      variant: props.variant,
      size: props.size,
      styleConfig: props.styleConfig
    }));
    var styles = useStyleConfig('Link', themingProps.value);
    return () => _createVNode(chakra.a, _mergeProps({
      "as": props.as,
      "__label": "link",
      "target": props.isExternal ? '_blank' : undefined,
      "rel": props.isExternal ? 'noopener noreferrer' : undefined,
      "__css": styles.value
    }, attrs), _isSlot(slots) ? slots : {
      default: () => [slots]
    });
  }

});
//# sourceMappingURL=link.js.map