import { createVNode as _createVNode, isVNode as _isVNode, mergeProps as _mergeProps } from "vue";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import { CIcon } from '@chakra-ui/c-icon';
import { useMultiStyleConfig, useStyles, StylesProvider } from '@chakra-ui/vue-system';
import { defineComponent, computed } from 'vue';
import { chakra } from '@chakra-ui/vue-system';
import { getValidChildren, SNAO, SAO } from '@chakra-ui/vue-utils';

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !_isVNode(s);
}

/**
 * List is used to display list items, it renders a `<ul>` by default.
 *
 * @see Docs https://vue.chakra-ui.com/docs/data-display/list
 */
export var CList = defineComponent({
  name: 'CList',
  props: {
    as: {
      type: [Object, String],
      default: 'ul'
    },
    styleType: {
      type: SAO,
      default: 'none'
    },
    stylePosition: SAO,
    spacing: SNAO
  },

  setup(props, _ref) {
    var {
      slots,
      attrs
    } = _ref;
    var styles = useMultiStyleConfig('List', props);
    StylesProvider(styles);
    var selector = '& > *:not(style) ~ *:not(style)';
    var spacingStyle = computed(() => props.spacing ? {
      [selector]: {
        mt: props.spacing
      }
    } : {});
    return () => {
      var validChildren = () => getValidChildren(slots);

      return _createVNode(chakra.ul, _mergeProps({
        "__label": "list",
        "as": props.as,
        "listStyleType": props.styleType,
        "listStylePosition": props.stylePosition,
        "role": "list",
        "__css": _extends({}, styles.value.container, spacingStyle.value)
      }, attrs), _isSlot(validChildren) ? validChildren : {
        default: () => [validChildren]
      });
    };
  }

});
export var COrderedList = defineComponent({
  name: 'COrderedList',

  setup(props, _ref2) {
    var {
      slots,
      attrs
    } = _ref2;
    return () => // @ts-ignore
    _createVNode(CList, _mergeProps({
      "styleType": "decimal",
      "marginStart": "1em"
    }, attrs), _isSlot(slots) ? slots : {
      default: () => [slots]
    });
  }

});
export var CUnorderedList = defineComponent({
  name: 'CUnorderedList',

  setup(props, _ref3) {
    var {
      slots,
      attrs
    } = _ref3;
    return () => // @ts-ignore
    _createVNode(CList, _mergeProps({
      "styleType": "initial",
      "marginStart": "1em"
    }, attrs), _isSlot(slots) ? slots : {
      default: () => [slots]
    });
  }

});
export var CListItem = defineComponent({
  name: 'CListItem',

  setup(_, _ref4) {
    var {
      slots,
      attrs
    } = _ref4;
    var styles = useStyles();
    return () => {
      return _createVNode(chakra.li, _mergeProps({
        "__label": "list__item",
        "__css": styles.value.item
      }, attrs), _isSlot(slots) ? slots : {
        default: () => [slots]
      });
    };
  }

});
export var CListIcon = defineComponent({
  name: 'CListIcon',

  setup(_, _ref5) {
    var {
      slots,
      attrs
    } = _ref5;
    var styles = useStyles();
    return () => {
      return (// @ts-expect-error
        _createVNode(CIcon, _mergeProps({
          "role": "presentation"
        }, attrs, {
          "__css": styles.value.icon
        }), _isSlot(slots) ? slots : {
          default: () => [slots]
        })
      );
    };
  }

});
//# sourceMappingURL=list.js.map