import { createVNode as _createVNode, isVNode as _isVNode, mergeProps as _mergeProps } from "vue";
import { defineComponent, computed } from 'vue';
import { SNAO } from '@chakra-ui/vue-utils';
import { CGrid } from './grid';
import { isNull, isNumber, mapResponsive } from '@chakra-ui/utils';

function _isSlot(s) {
  return typeof s === 'function' || Object.prototype.toString.call(s) === '[object Object]' && !_isVNode(s);
}

/**
 * SimpleGrid
 *
 * Vue component make that providers a simpler interface, and
 * make its easy to create responsive grid layouts.
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/simple-grid
 */
export var CSimpleGrid = defineComponent({
  name: 'CSimpleGrid',
  props: {
    as: {
      type: [Object, String],
      default: 'ul'
    },
    minChildWidth: SNAO,
    columns: SNAO,
    spacing: SNAO,
    spacingX: SNAO,
    spacingY: SNAO
  },

  setup(props, _ref) {
    var {
      slots,
      attrs
    } = _ref;
    var templateColumns = computed(() => props.minChildWidth ? widthToColumns(props.minChildWidth) : countToColumns(props.columns));
    return () => _createVNode(CGrid, _mergeProps({
      "as": props.as,
      "__label": "simple-grid",
      "gap": props.spacing,
      "columnGap": props.spacingX,
      "rowGap": props.spacingY,
      "templateColumns": templateColumns.value
    }, attrs), _isSlot(slots) ? slots : {
      default: () => [slots]
    });
  }

});

function toPx(n) {
  return isNumber(n) ? n + "px" : n;
}

function widthToColumns(width) {
  return mapResponsive(width, value => isNull(value) ? null : "repeat(auto-fit, minmax(" + toPx(value) + ", 1fr))");
}

function countToColumns(count) {
  return mapResponsive(count, value => isNull(value) ? null : "repeat(" + value + ", minmax(0, 1fr))");
}
//# sourceMappingURL=simple-grid.js.map