import { HTMLChakraProps, SystemProps } from '@chakra-ui/vue-system';
import { PropType } from '@vue/runtime-core';
export interface WrapProps extends HTMLChakraProps<'div'> {
    /**
     * The space between the each child (even if it wraps)
     * @type SystemProps["margin"]
     */
    spacing?: SystemProps['margin'];
    /**
     * The `justify-content` value (for cross-axis alignment)
     * @type SystemProps["justifyContent"]
     */
    justify?: SystemProps['justifyContent'];
    /**
     * The `align-items` value (for main axis alignment)
     * @type SystemProps["alignItems"]
     */
    align?: SystemProps['alignItems'];
    /**
     * The `flex-direction` value
     * @type SystemProps["flexDirection"]
     */
    direction?: SystemProps['flexDirection'];
    /**
     * If `true`, the children will be wrapped in a `WrapItem`
     */
    shouldWrapChildren?: boolean;
}
/**
 * Used to render texts or paragraphs.
 *
 * @see Docs https://vue.chakra-ui.com/docs/typography/text
 */
export declare const CWrap: import("@vue/runtime-core").DefineComponent<{
    as: {
        type: PropType<"a" | "article" | "aside" | "b" | "blockquote" | "button" | "caption" | "cite" | "code" | "dd" | "div" | "dl" | "dt" | "fieldset" | "figcaption" | "figure" | "footer" | "form" | "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "header" | "hr" | "iframe" | "img" | "input" | "kbd" | "label" | "li" | "main" | "mark" | "nav" | "ol" | "p" | "pre" | "q" | "s" | "section" | "select" | "small" | "span" | "strong" | "sub" | "sup" | "table" | "tbody" | "td" | "textarea" | "tfoot" | "th" | "thead" | "tr" | "ul" | "svg" | "circle" | "path" | "rect">;
        default: string;
    };
    spacing: PropType<import("@chakra-ui/vue-system").ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "-1" | "2" | "-2" | "3" | "-3" | "4" | "-4" | "5" | "-5" | "6" | "-6" | "7" | "-7" | "8" | "-8" | "9" | "-9" | "10" | "-10" | "12" | "-12" | "14" | "-14" | "16" | "-16" | "20" | "-20" | "24" | "-24" | "28" | "-28" | "32" | "-32" | "36" | "-36" | "40" | "-40" | "44" | "-44" | "48" | "-48" | "52" | "-52" | "56" | "-56" | "60" | "-60" | "64" | "-64" | "72" | "-72" | "80" | "-80" | "96" | "-96" | "-px" | "0.5" | "-0.5" | "1.5" | "-1.5" | "2.5" | "-2.5" | "3.5" | "-3.5">> | undefined>;
    justify: PropType<import("@chakra-ui/vue-system").ResponsiveValue<import("csstype").Property.JustifyContent> | undefined>;
    align: PropType<import("@chakra-ui/vue-system").ResponsiveValue<import("csstype").Property.AlignItems> | undefined>;
    direction: PropType<import("@chakra-ui/vue-system").ResponsiveValue<import("csstype").Property.FlexDirection> | undefined>;
    shouldWrapChildren: PropType<boolean | undefined>;
}, () => import("@vue/runtime-core").VNode<import("@vue/runtime-core").RendererNode, import("@vue/runtime-core").RendererElement, {
    [key: string]: any;
}>, unknown, {}, {}, import("@vue/runtime-core").ComponentOptionsMixin, import("@vue/runtime-core").ComponentOptionsMixin, Record<string, any>, string, import("@vue/runtime-core").VNodeProps & import("@vue/runtime-core").AllowedComponentProps & import("@vue/runtime-core").ComponentCustomProps, Readonly<{
    as?: unknown;
    spacing?: unknown;
    justify?: unknown;
    align?: unknown;
    direction?: unknown;
    shouldWrapChildren?: unknown;
} & {
    as: "a" | "article" | "aside" | "b" | "blockquote" | "button" | "caption" | "cite" | "code" | "dd" | "div" | "dl" | "dt" | "fieldset" | "figcaption" | "figure" | "footer" | "form" | "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "header" | "hr" | "iframe" | "img" | "input" | "kbd" | "label" | "li" | "main" | "mark" | "nav" | "ol" | "p" | "pre" | "q" | "s" | "section" | "select" | "small" | "span" | "strong" | "sub" | "sup" | "table" | "tbody" | "td" | "textarea" | "tfoot" | "th" | "thead" | "tr" | "ul" | "svg" | "circle" | "path" | "rect";
} & {
    direction?: import("@chakra-ui/vue-system").ResponsiveValue<import("csstype").Property.FlexDirection> | undefined;
    justify?: import("@chakra-ui/vue-system").ResponsiveValue<import("csstype").Property.JustifyContent> | undefined;
    spacing?: import("@chakra-ui/vue-system").ResponsiveValue<import("@chakra-ui/styled-system/dist/types/utils").Union<number | "px" | (string & {}) | "-moz-initial" | "inherit" | "initial" | "revert" | "unset" | "auto" | "1" | "-1" | "2" | "-2" | "3" | "-3" | "4" | "-4" | "5" | "-5" | "6" | "-6" | "7" | "-7" | "8" | "-8" | "9" | "-9" | "10" | "-10" | "12" | "-12" | "14" | "-14" | "16" | "-16" | "20" | "-20" | "24" | "-24" | "28" | "-28" | "32" | "-32" | "36" | "-36" | "40" | "-40" | "44" | "-44" | "48" | "-48" | "52" | "-52" | "56" | "-56" | "60" | "-60" | "64" | "-64" | "72" | "-72" | "80" | "-80" | "96" | "-96" | "-px" | "0.5" | "-0.5" | "1.5" | "-1.5" | "2.5" | "-2.5" | "3.5" | "-3.5">> | undefined;
    align?: import("@chakra-ui/vue-system").ResponsiveValue<import("csstype").Property.AlignItems> | undefined;
    shouldWrapChildren?: boolean | undefined;
}>, {
    as: "a" | "article" | "aside" | "b" | "blockquote" | "button" | "caption" | "cite" | "code" | "dd" | "div" | "dl" | "dt" | "fieldset" | "figcaption" | "figure" | "footer" | "form" | "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "header" | "hr" | "iframe" | "img" | "input" | "kbd" | "label" | "li" | "main" | "mark" | "nav" | "ol" | "p" | "pre" | "q" | "s" | "section" | "select" | "small" | "span" | "strong" | "sub" | "sup" | "table" | "tbody" | "td" | "textarea" | "tfoot" | "th" | "thead" | "tr" | "ul" | "svg" | "circle" | "path" | "rect";
}>;
export interface WrapItemProps extends HTMLChakraProps<'li'> {
}
export declare const CWrapItem: import("@vue/runtime-core").DefineComponent<{}, () => import("@vue/runtime-core").VNode<import("@vue/runtime-core").RendererNode, import("@vue/runtime-core").RendererElement, {
    [key: string]: any;
}>, {}, {}, {}, import("@vue/runtime-core").ComponentOptionsMixin, import("@vue/runtime-core").ComponentOptionsMixin, import("@vue/runtime-core").EmitsOptions, string, import("@vue/runtime-core").VNodeProps & import("@vue/runtime-core").AllowedComponentProps & import("@vue/runtime-core").ComponentCustomProps, Readonly<{} & {} & {}>, {}>;
